Event

Struct Event 

pub struct Event { /* private fields */ }
An event that represents a single point in time during the execution of a span.

Implementations

Source

impl Event

pub fn new(name: impl Into<Cow<'static, str>>) -> Self

Create a new event with the given name.

Examples
use fastrace::prelude::*;

LocalSpan::add_event(Event::new("event"));
pub fn with_property<K, V, F>(self, property: F) -> Self
where K: Into<Cow<'static, str>>, V: Into<Cow<'static, str>>, F: FnOnce() -> (K, V),

Add a single property to the Event and return the modified Event.

A property is an arbitrary key-value pair associated with an event.

Examples
use fastrace::prelude::*;

LocalSpan::add_event(Event::new("event").with_property(|| ("key", "value")));
pub fn with_properties<K, V, I, F>(self, properties: F) -> Self
where K: Into<Cow<'static, str>>, V: Into<Cow<'static, str>>, I: IntoIterator<Item = (K, V)>, F: FnOnce() -> I,

Add multiple properties to the Event and return the modified Event.

Examples
use fastrace::prelude::*;

LocalSpan::add_event(Event::new("event").with_properties(|| [("key1", "value")]));
pub fn add_to_parent<I, F>( name: impl Into<Cow<'static, str>>, parent: &Span, properties: F, )
where I: IntoIterator<Item = (Cow<'static, str>, Cow<'static, str>)>, F: FnOnce() -> I,

👎Deprecated since 0.7.8: use Span::add_event instead

Adds an event to the parent span with the given name and properties.

Examples
use fastrace::prelude::*;

let root = Span::root("root", SpanContext::random());

Event::add_to_parent("event in root", &root, || [("key".into(), "value".into())]);
pub fn add_to_local_parent<I, F>( name: impl Into<Cow<'static, str>>, properties: F, )
where I: IntoIterator<Item = (Cow<'static, str>, Cow<'static, str>)>, F: FnOnce() -> I,

👎Deprecated since 0.7.8: use LocalSpan::add_event instead

Adds an event to the current local parent span with the given name and properties.

Examples
use fastrace::prelude::*;

let root = Span::root("root", SpanContext::random());
let _guard = root.set_local_parent();

Event::add_to_local_parent("event in root", || [("key".into(), "value".into())]);